@@ -1,5 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2011,2013 Colin Walters <walters@verbum.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -35,5 +34,14 @@
 #include <ostree-diff.h>
 #include <ostree-gpg-verify-result.h>
 
+#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
+#include <ostree-ref.h>
+#include <ostree-repo-finder.h>
+#include <ostree-repo-finder-avahi.h>
+#include <ostree-repo-finder-config.h>
+#include <ostree-repo-finder-mount.h>
+#include <ostree-repo-finder-override.h>
+#endif /* OSTREE_ENABLE_EXPERIMENTAL_API */
+
 #include <ostree-autocleanups.h>
 #include <ostree-version.h>
